/*  Project TabMain
    DHB Software
    Copyright  1995. All Rights Reserved.

	SUBSYSTEM:    tabmain.exe Application
	FILE:         tbmtdlgc.cpp
	AUTHOR:       David H. Borg


	OVERVIEW
	========
	Source file for implementation of TabMainTDLGClient (TDialog).
*/


#include <owl\owlpch.h>
#pragma hdrstop

#include <stdio.h>
#include "tabmnapp.hpp"
#include "tabmnapp.h"
#include "tbmtdlgc.h"


// transfer structures for the tabbed dialogs
extern TabDialog1Xfer txDialog1;
extern TabDialog2Xfer txDialog2;
extern TabDialog3Xfer txDialog3;

//
// Build a response table for all messages/commands handled
// by the application.
//
DEFINE_RESPONSE_TABLE1(TabMainTDLGClient, TDialog)
//{{TabMainTDLGClientRSP_TBL_BEGIN}}
	EV_MESSAGE( WM_CHANGEFRAMESTYLE, CmChangeFrameStyle),
	EV_MESSAGE( WM_DIALOGISMODIFIED, CmDialogIsModified),
	EV_MESSAGE( WM_NOTIFY, EvTabControlNotify),
	EV_BN_CLICKED(IDOK, BNClickedOk),
	EV_BN_CLICKED(IDC_ABOUT, BNClickedAbout),
	EV_BN_CLICKED(IDC_APPLY, BNClickedApply),
//{{TabMainTDLGClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//{{TabMainTDLGClient Implementation}}


//////////////////////////////////////////////////////////
// TabMainTDLGClient
// ==========
// Construction/Destruction handling.
TabMainTDLGClient::TabMainTDLGClient (TWindow *parent, TResId resId, TModule *module)
	: TDialog(parent, resId, module), tc(0), dialog1(0), dialog2(0), dialog3(0)
{
	// INSERT>> Your constructor code here.

	// the apply button is enabled when the dialogs have been modified
	apply = new TButton( this, IDC_APPLY);

	// initialize dialog transfer structures
	txDialog1.cpu386 = txDialog1.cpu486 = false;
	txDialog1.cpuPentium = true;
	txDialog2.mouse = txDialog2.soundcard = BF_CHECKED;
	txDialog2.cdrom = BF_UNCHECKED;
	strcpy( txDialog3.compiler, "Borland C++");

	// load the Windows 95 common controls DLL
	InitCommonControls();            
}


TabMainTDLGClient::~TabMainTDLGClient ()
{
	Destroy();

	// INSERT>> Your destructor code here.

	// Destroy the tab control and all dialogs
	if( tc)
		tc->Destroy();
	if( dialog1)
		dialog1->Destroy();
	if( dialog2)
		dialog2->Destroy();
	if( dialog3)
		dialog3->Destroy();

	delete tc, dialog1, dialog2, dialog3;
	tc = 0;
	dialog1 = 0;
	dialog2 = 0;
	dialog3 = 0;
}


void TabMainTDLGClient::SetupWindow ()
{
	TDialog::SetupWindow();

	// INSERT>> Your code here.

	CreateTabs();
	CreateDialogs();
	apply->EnableWindow( false);

	// All the children and siblings of the frame have been created.
	// Post a message to call a function to change the frame styles.
	PostMessage( WM_CHANGEFRAMESTYLE, 0, 0 );
}


void TabMainTDLGClient::CreateTabs ()
{
	RECT rc;
	HBITMAP hBitmap;
	int image1, image2, image3;

	// create a tab control window smaller than the client window
	::GetClientRect( HWindow, &rc);
	tc = new TabControl( this, ID_TABCONTROL, rc.left + 5, rc.top + 5,
							rc.right - 10, rc.bottom - 60);
	tc->Create();

	// create an image list to display with the text on each tab
	hIML = ImageList_Create(20, 20, FALSE, 3, 0);

	// add the bitmaps to the image list
	hBitmap = GetModule()->LoadBitmap( TResId( IDB_TAB1));
	image1 = ImageList_Add(hIML, hBitmap, (HBITMAP)NULL);
	hBitmap = GetModule()->LoadBitmap( TResId( IDB_TAB2));
	image2 = ImageList_Add(hIML, hBitmap, (HBITMAP)NULL);
	hBitmap = GetModule()->LoadBitmap( TResId( IDB_TAB3));
	image3 = ImageList_Add(hIML, hBitmap, (HBITMAP)NULL);

	// Set image list
	SendDlgItemMessage( ID_TABCONTROL, TCM_SETIMAGELIST, (WPARAM)0,
					(LPARAM)(HIMAGELIST)hIML);

	// Initialize arrays for tabs
	tcItem[0].mask = TCIF_TEXT | TCIF_IMAGE;	// display text and bmp on tabs
	tcItem[0].pszText = "CPU";					// text to display on tab
	tcItem[0].iImage = image1;					// bitmap to display on tab
	tcItem[1].mask = TCIF_TEXT | TCIF_IMAGE;	// display text and bmp on tabs
	tcItem[1].pszText = "Hardware";				// text to display on tab
	tcItem[1].iImage = image2;					// bitmap to display on tab
	tcItem[2].mask = TCIF_TEXT | TCIF_IMAGE;	// display text and bmp on tabs
	tcItem[2].pszText = "Compiler";				// text to display on tab
	tcItem[2].iImage = image3;					// bitmap to display on tab
	SendDlgItemMessage( ID_TABCONTROL, TCM_INSERTITEM, (WPARAM)(int)0,
					(LPARAM)(const TC_ITEM FAR*)&tcItem[0]);
	SendDlgItemMessage( ID_TABCONTROL, TCM_INSERTITEM, (WPARAM)(int)1,
					(LPARAM)(const TC_ITEM FAR*)&tcItem[1]);
	SendDlgItemMessage( ID_TABCONTROL, TCM_INSERTITEM, (WPARAM)(int)2,
					(LPARAM)(const TC_ITEM FAR*)&tcItem[2]);
}


// this creates the dialogs that are overlayed when a tab is selected.
void TabMainTDLGClient::CreateDialogs ()
{
	dialog1 = new TabDialog1( this);
	dialog1->Create();
	dialog2 = new TabDialog2( this);
	dialog2->Create();
	dialog3 = new TabDialog3( this);
	dialog3->Create();

	dialog1->ShowWindow( SW_SHOW);
	dialog2->ShowWindow( SW_HIDE);
	dialog3->ShowWindow( SW_HIDE);
}


// This function is a bug_fix/work_around downloaded from the Borland BBS.
// This allows fixed frames to shrunk-to-fit around dialog main windows.
// Slight modifications have been made to suit this application.
LRESULT TabMainTDLGClient::CmChangeFrameStyle(WPARAM /*wParam*/, LPARAM /*lParam*/ )
{
	long style, exStyle;

	TDecoratedFrame* frame = TYPESAFE_DOWNCAST(GetApplication()->GetMainWindow(), TDecoratedFrame);

	frame->ClearFlag( wfShrinkToClient );
	frame->Layout();

	// my modification to eliminate the thin border on the main dialog
	style = GetWindowLong( GWL_STYLE );
	style &= ~(WS_BORDER);
	SetWindowLong( GWL_STYLE, style );

	// Redraw the dialog.
	SetWindowPos( 0, 0, 0, 0, 0, SWP_NOZORDER | SWP_NOMOVE |
								 SWP_NOSIZE | SWP_DRAWFRAME );

	style = frame->GetWindowLong( GWL_STYLE );
	style &= ~(WS_THICKFRAME);
	frame->SetWindowLong( GWL_STYLE, style );

	// my modification to give the dialog a thick frame again
	exStyle = frame->GetWindowLong( GWL_EXSTYLE );
	exStyle |= WS_EX_DLGMODALFRAME;
	frame->SetWindowLong( GWL_EXSTYLE, exStyle );

	// Redraw the frame.
	frame->SetWindowPos( 0, 0, 0, 0, 0, SWP_NOZORDER | SWP_NOMOVE |
										SWP_NOSIZE | SWP_DRAWFRAME );
	return 0;
}


// One of the tab dialogs has been modified so enable the apply button
LRESULT TabMainTDLGClient::CmDialogIsModified(WPARAM /*wParam*/, LPARAM /*lParam*/ )
{
	apply->EnableWindow( true);
	return 0;
}


// This function handles the messages sent by Windows 95 custom controls.
LRESULT TabMainTDLGClient::EvTabControlNotify( WPARAM /*wParam*/, LPARAM lParam)
{
	int tab;
	NMHDR FAR *pNmhdr = (NMHDR FAR *)lParam;

	switch( pNmhdr->code){
		case TCN_SELCHANGE:		// process tab control message
			// find out which tab was selected and show its dialog
			tab = (int)::SendMessage( (HWND)pNmhdr->hwndFrom, TCM_GETCURSEL, 0, 0);
			switch(tab){
				case 0:
					dialog1->ShowWindow( SW_SHOW);
					dialog2->ShowWindow( SW_HIDE);
					dialog3->ShowWindow( SW_HIDE);
					break;
				case 1:
					dialog1->ShowWindow( SW_HIDE);
					dialog2->ShowWindow( SW_SHOW);
					dialog3->ShowWindow( SW_HIDE);
					break;
				case 2:
					dialog1->ShowWindow( SW_HIDE);
					dialog2->ShowWindow( SW_HIDE);
					dialog3->ShowWindow( SW_SHOW);
					break;
			}
			break;

		case TTN_NEEDTEXT:		// process tool tip control message
			{
				LPTOOLTIPTEXT lpText;

				lpText = (LPTOOLTIPTEXT)lParam;
				lpText->hinst = GetModule()->GetInstance();
				lpText->lpszText = MAKEINTRESOURCE(IDS_TAB_TIP);
			}
			break;

		default:
			break;
	}
	return 0;
}


void TabMainTDLGClient::BNClickedOk ()
{
	// INSERT>> Your code here.

	ShowSelections();
	CmOk();
}


void TabMainTDLGClient::BNClickedAbout ()
{
	// INSERT>> Your code here.

	TDialog( this, IDD_ABOUTDLG).Execute();
}


// If the apply button is enabled, the selections will be shown
void TabMainTDLGClient::BNClickedApply ()
{
	// INSERT>> Your code here.

	ShowSelections();
	apply->EnableWindow( false);
}


// Transfer data from dialog boxes and display results of selection.
void TabMainTDLGClient::ShowSelections()
{
	char buf[1024];
	char *str;

	dialog1->TransferData( tdGetData);
	dialog2->TransferData( tdGetData);
	dialog3->TransferData( tdGetData);

	if( txDialog1.cpu386)
		str = "386";
	else if( txDialog1.cpu486)
		str = "486";
	else
		str = "Pentium";

	sprintf( buf, "DATA SELECTED IS:\n\nProcessor = %s\n"
			  "Hardware = %s, %s, and %s\n"
			  "Compiler = %s", str,
			  txDialog2.mouse == BF_CHECKED ? "Mouse" : "none",
			  txDialog2.soundcard == BF_CHECKED ? "Soundcard" : "none",
			  txDialog2.cdrom == BF_CHECKED ? "CD-ROM" : "none",
			  txDialog3.compiler);
	MessageBox( buf, "TabMain", MB_OK);
}
